pub(crate) struct LayerFill {
pub(crate) span: Span,
alpha_idx: Option<AlphaIdx>,
pub(crate) attrs_idx: u32,
}Expand description
Composite a span from the current temporary layer buffer into the parent buffer and optionally apply some alpha coverage.
Fields
span: Spanalpha_idx: Option<AlphaIdx>attrs_idx: u32Implementations