pub(crate) struct LayerFillAttrs {
pub(crate) blend_mode: BlendMode,
pub(crate) opacity: f32,
pub(crate) mask: Option<Mask>,
pub(crate) draw_id: u32,
pub(crate) thread_idx: u8,
}Fields
blend_mode: BlendModeopacity: f32mask: Option<Mask>draw_id: u32thread_idx: u8In case there is any alpha associated with the layer command, this stores the index of the thread that stores the alpha.